==> py_pdf_term-1.0.0.tar.gz: py_pdf_term-1.0.0/py_pdf_term/endtoend/_endtoend/mappers/candidates/filter.py <==
from typing import Type

from py_pdf_term._common.consts import PACKAGE_NAME
from py_pdf_term.candidates.filters import (
    BaseCandidateTermFilter,
    BaseCandidateTokenFilter,
    EnglishConcatenationFilter,
    EnglishNumericFilter,
    EnglishProperNounFilter,
    EnglishSymbolLikeFilter,
    EnglishTokenFilter,
    JapaneseConcatenationFilter,
    JapaneseNumericFilter,
    JapaneseProperNounFilter,
    JapaneseSymbolLikeFilter,
    JapaneseTokenFilter,
)

from ..base import BaseMapper


class CandidateTokenFilterMapper(BaseMapper[Type[BaseCandidateTokenFilter]]):
    """A mapper to find candidate token filter classes."""

    @classmethod
    def default_mapper(cls) -> "CandidateTokenFilterMapper":
        default_mapper = cls()

        token_filter_clses = [JapaneseTokenFilter, EnglishTokenFilter]
        for filter_cls in token_filter_clses:
            default_mapper.add(f"{PACKAGE_NAME}.{filter_cls.__name__}", filter_cls)

        return default_mapper


class CandidateTermFilterMapper(BaseMapper[Type[BaseCandidateTermFilter]]):
    """A mapper to find candidate term filter classes."""

    @classmethod
    def default_mapper(cls) -> "CandidateTermFilterMapper":
        default_mapper = cls()

        term_filter_clses = [
            JapaneseConcatenationFilter,
            EnglishConcatenationFilter,
            JapaneseSymbolLikeFilter,
            EnglishSymbolLikeFilter,
            JapaneseProperNounFilter,
            EnglishProperNounFilter,
            JapaneseNumericFilter,
            EnglishNumericFilter,
        ]
        for filter_cls in term_filter_clses:
            default_mapper.add(f"{PACKAGE_NAME}.{filter_cls.__name__}", filter_cls)

        return default_mapper

==> py_pdf_term-1.0.2.tar.gz: py_pdf_term-1.0.2/py_pdf_term/endtoend/_endtoend/mappers/candidates/filter.py <==
from py_pdf_term._common.consts import PACKAGE_NAME
from py_pdf_term.candidates.filters import (
    BaseCandidateTermFilter,
    BaseCandidateTokenFilter,
    EnglishConcatenationFilter,
    EnglishNumericFilter,
    EnglishProperNounFilter,
    EnglishSymbolLikeFilter,
    EnglishTokenFilter,
    JapaneseConcatenationFilter,
    JapaneseNumericFilter,
    JapaneseProperNounFilter,
    JapaneseSymbolLikeFilter,
    JapaneseTokenFilter,
)

from ..base import BaseMapper


class CandidateTokenFilterMapper(BaseMapper[type[BaseCandidateTokenFilter]]):
    """Mapper to find candidate token filter classes."""

    @classmethod
    def default_mapper(cls) -> "CandidateTokenFilterMapper":
        default_mapper = cls()

        token_filter_clses = [JapaneseTokenFilter, EnglishTokenFilter]
        for filter_cls in token_filter_clses:
            default_mapper.add(f"{PACKAGE_NAME}.{filter_cls.__name__}", filter_cls)

        return default_mapper


class CandidateTermFilterMapper(BaseMapper[type[BaseCandidateTermFilter]]):
    """Mapper to find candidate term filter classes."""

    @classmethod
    def default_mapper(cls) -> "CandidateTermFilterMapper":
        default_mapper = cls()

        term_filter_clses = [
            JapaneseConcatenationFilter,
            EnglishConcatenationFilter,
            JapaneseSymbolLikeFilter,
            EnglishSymbolLikeFilter,
            JapaneseProperNounFilter,
            EnglishProperNounFilter,
            JapaneseNumericFilter,
            EnglishNumericFilter,
        ]
        for filter_cls in term_filter_clses:
            default_mapper.add(f"{PACKAGE_NAME}.{filter_cls.__name__}", filter_cls)

        return default_mapper
